@@ -1,16 +1,42 @@
 use strict;
 use warnings;
-package MooseX::SetOnce;
-{
-  $MooseX::SetOnce::VERSION = '0.200001';
-}
+package MooseX::SetOnce 0.202;
 # ABSTRACT: write-once, read-many attributes for Moose
 
+#pod =head1 SYNOPSIS
+#pod
+#pod Add the "SetOnce" trait to attributes:
+#pod
+#pod   package Class;
+#pod   use Moose;
+#pod   use MooseX::SetOnce;
+#pod
+#pod   has some_attr => (
+#pod     is     => 'rw',
+#pod     traits => [ qw(SetOnce) ],
+#pod   );
+#pod
+#pod ...and then you can only set them once:
+#pod
+#pod   my $object = Class->new;
+#pod
+#pod   $object->some_attr(10);  # works fine
+#pod   $object->some_attr(20);  # throws an exception: it's already set!
+#pod
+#pod =head1 DESCRIPTION
+#pod
+#pod The 'SetOnce' attribute lets your class have attributes that are not lazy and
+#pod not set, but that cannot be altered once set.
+#pod
+#pod The logic is very simple:  if you try to alter the value of an attribute with
+#pod the SetOnce trait, either by accessor or writer, and the attribute has a value,
+#pod it will throw an exception.
+#pod
+#pod If the attribute has a clearer, you may clear the attribute and set it again.
+#pod
+#pod =cut
 
-package MooseX::SetOnce::Attribute;
-{
-  $MooseX::SetOnce::Attribute::VERSION = '0.200001';
-}
+package MooseX::SetOnce::Attribute 0.202;
 use Moose::Role 0.90;
 
 before set_value => sub { $_[0]->_ensure_unset($_[1]) };
@@ -46,10 +72,7 @@ around accessor_metaclass => sub {
   )->name
 } if $Moose::VERSION < 1.9900;
 
-package MooseX::SetOnce::Accessor;
-{
-  $MooseX::SetOnce::Accessor::VERSION = '0.200001';
-}
+package MooseX::SetOnce::Accessor 0.202;
 use Moose::Role 0.90;
 
 around _inline_store => sub {
@@ -65,24 +88,24 @@ around _inline_store => sub {
   return $code;
 };
 
-package Moose::Meta::Attribute::Custom::Trait::SetOnce;
-{
-  $Moose::Meta::Attribute::Custom::Trait::SetOnce::VERSION = '0.200001';
-}
+package Moose::Meta::Attribute::Custom::Trait::SetOnce 0.202;
 sub register_implementation { 'MooseX::SetOnce::Attribute' }
 
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 MooseX::SetOnce - write-once, read-many attributes for Moose
 
 =head1 VERSION
 
-version 0.200001
+version 0.202
 
 =head1 SYNOPSIS
 
@@ -117,14 +140,37 @@ If the attribute has a clearer, you may clear the attribute and set it again.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <cpan@semiotic.systems>
+
+=head1 CONTRIBUTORS
+
+=for stopwords Jesse Luehrs Karen Etheridge Kent Fredric Ricardo Signes
+
+=over 4
+
+=item *
+
+Jesse Luehrs <doy@tozt.net>
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Kent Fredric <kentfredric@gmail.com>
+
+=item *
+
+Ricardo Signes <rjbs@semiotic.systems>
+
+=back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Ricardo SIGNES.
+This software is copyright (c) 2022 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
